@@ -5,7 +5,7 @@ pub struct Point(f64, f64, f64);
 
 #[rustfmt::skip]
 impl Projective3D<f64> for Point {
-    fn transform(self, matrix: &[f64; 16]) -> Self {
+    fn transform(&self, matrix: &[&f64; 16]) -> Self {
         Point(
             matrix[0] * self.0 + matrix[1] * self.1 + matrix[2] * self.2 + matrix[3],
             matrix[4] * self.0 + matrix[5] * self.1 + matrix[6] * self.2 + matrix[7],
@@ -17,6 +17,6 @@ impl Projective3D<f64> for Point {
 #[test]
 fn test_transform() {
     let p0 = Point(1.0, 2.0, 3.0);
-    assert_eq!(p0.translate(3.0, 2.0, 1.0), Point(4.0, 4.0, 4.0));
-    assert_eq!(p0.scale(1.0, 2.0, 3.0), Point(1.0, 4.0, 9.0));
+    assert_eq!(p0.translate(&3.0, &2.0, &1.0), Point(4.0, 4.0, 4.0));
+    assert_eq!(p0.scale(&1.0, &2.0, &3.0), Point(1.0, 4.0, 9.0));
 }
